.. highlight:: shell

============
Contributing
============

Contributions are welcome, and they are greatly appreciated! 

You can contribute in several ways:

Report Bugs
~~~~~~~~~~~

Report bugs at https://github.com/at621/credit_risk_validation_tests/issues.

If you are reporting a bug, please include:

* Your operating system name and version.
* Any details about your local setup that might be helpful in troubleshooting.
* Detailed steps to reproduce the bug.

New features
~~~~~~~~~~~~~~~
All features requests are welcome, including for including additional tests. The main constraint is that the feature should be related to credit risk modelling.

If you are proposing a feature:
* Explain in some detail how it would work
* Add references to publicly available documentation


Submit Feedback
~~~~~~~~~~~~~~~
The best way to send feedback is to e-mail: anton.treialt@aistat.com